==> pmd-src-3.9.zip: pmd-3.9/regress/test/net/sourceforge/pmd/SimpleRuleSetNameMapperTest.java <==
package test.net.sourceforge.pmd;

import junit.framework.TestCase;
import net.sourceforge.pmd.SimpleRuleSetNameMapper;

public class SimpleRuleSetNameMapperTest extends TestCase {

    public void testMultipleSimple() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("unusedcode,basic");
        assertEquals("rulesets/unusedcode.xml,rulesets/basic.xml", s.getRuleSets());
    }

    public void testOneSimple() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("basic");
        assertEquals("rulesets/basic.xml", s.getRuleSets());
    }

    public void testMultipleRegular() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("rulesets/unusedcode.xml,rulesets/basic.xml");
        assertEquals("rulesets/unusedcode.xml,rulesets/basic.xml", s.getRuleSets());
    }

    public void testOneRegular() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("rulesets/unusedcode.xml");
        assertEquals("rulesets/unusedcode.xml", s.getRuleSets());
    }

    public void testMix() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("rulesets/unusedcode.xml,basic");
        assertEquals("rulesets/unusedcode.xml,rulesets/basic.xml", s.getRuleSets());
    }

    public void testUnknown() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("favorites.xml");
        assertEquals("favorites.xml", s.getRuleSets());
    }

    public void testUnknownAndSimple() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("basic,favorites.xml");
        assertEquals("rulesets/basic.xml,favorites.xml", s.getRuleSets());
    }
}

==> pmd-src-4.2.5.zip: pmd-4.2.5/regress/test/net/sourceforge/pmd/SimpleRuleSetNameMapperTest.java <==
package test.net.sourceforge.pmd;

import static org.junit.Assert.assertEquals;
import net.sourceforge.pmd.SimpleRuleSetNameMapper;

import org.junit.Test;

import junit.framework.JUnit4TestAdapter;

public class SimpleRuleSetNameMapperTest {

    @Test
    public void testMultipleSimple() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("unusedcode,basic");
        assertEquals("rulesets/unusedcode.xml,rulesets/basic.xml", s.getRuleSets());
    }

    @Test
    public void testOneSimple() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("basic");
        assertEquals("rulesets/basic.xml", s.getRuleSets());
    }

    @Test
    public void testMultipleRegular() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("rulesets/unusedcode.xml,rulesets/basic.xml");
        assertEquals("rulesets/unusedcode.xml,rulesets/basic.xml", s.getRuleSets());
    }

    @Test
    public void testOneRegular() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("rulesets/unusedcode.xml");
        assertEquals("rulesets/unusedcode.xml", s.getRuleSets());
    }

    @Test
    public void testMix() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("rulesets/unusedcode.xml,basic");
        assertEquals("rulesets/unusedcode.xml,rulesets/basic.xml", s.getRuleSets());
    }

    @Test
    public void testUnknown() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("favorites.xml");
        assertEquals("favorites.xml", s.getRuleSets());
    }

    @Test
    public void testUnknownAndSimple() {
        SimpleRuleSetNameMapper s = new SimpleRuleSetNameMapper("basic,favorites.xml");
        assertEquals("rulesets/basic.xml,favorites.xml", s.getRuleSets());
    }

    public static junit.framework.Test suite() {
        return new JUnit4TestAdapter(SimpleRuleSetNameMapperTest.class);
    }
}
